Enum rapid_time::DateTime

source ·
pub enum DateTime {
    Earliest,
    Point(TimePoint),
    Latest,
}
Represents a point in time.

  • The smallest unit is seconds.
  • Leap years are integrated but no daylight-saving.
  • In addition to an actual point in time, it can also be Earliest or Latest, which is the smallest and largest element in the Ordering.
  • A Durations can be added or subtracted to obtain a new DateTime.
  • Two DateTime can be subtracted to obtain a Duration. (Note that the left operand must be later than the right operand, as negative durations are not allowed.)

Variants



Earliest

The earliest possible point in time. (Smaller than all other DateTimes.)



Point(TimePoint)

An actual point in time.



Latest

The latest possible point in time. (Larger than all other DateTimes.)

Implementations

source

impl DateTime

source

pub fn new(string: &str) -> DateTime

Creates a new DateTime from a string. The string must be in the format “2009-06-15T13:45:13” or “2009-4-15T12:10”.

source

impl DateTime

source

pub fn as_iso(&self) -> String

Returns the DateTime as a string in the format “2009-06-15T13:45:13”.