Enum rapid_time::DateTime
source · pub enum DateTime {
Earliest,
Point(TimePoint),
Latest,
}Expand description
Represents a point in time.
- The smallest unit is seconds.
- Leap years are integrated but no daylight-saving.
- In addition to an actual point in time, it can also be
EarliestorLatest, which is the smallest and largest element in the Ordering. - A
Durationscan be added or subtracted to obtain a newDateTime. - Two
DateTimecan be subtracted to obtain aDuration. (Note that the left operand must be later than the right operand, as negative durations are not allowed.)
Variants
Earliest
The earliest possible point in time. (Smaller than all other DateTimes.)
Point(TimePoint)
An actual point in time.
Latest
The latest possible point in time. (Larger than all other DateTimes.)
Implementations